@@ -130,10 +130,8 @@ class TableFactorFrozenQuery(FactorFrozenQuery):
     def _post_process(self, result: py2neo.database.Cursor, squeeze: bool = True) -> Table:
         t = super()._post_process(result, squeeze)
         if len(t):
-            try:
-                t.rename_columns(t.colnames, self.return_keys)
-            except AttributeError:
-                pass
+            t = Table(t)
+            t.rename_columns(t.colnames, self.return_keys)
         else:
             t = Table(names=self.return_keys)
         return t
